import React, { useState, useEffect, memo, useCallback } from 'react';
import { Link } from 'react-router-dom';
import { Menu, X } from 'lucide-react';
import Button from '../ui/Button';

const Header = memo(() => {
  const [isScrolled, setIsScrolled] = useState(false);
  const [isMenuOpen, setIsMenuOpen] = useState(false);

  const handleScroll = useCallback(() => {
    setIsScrolled(window.scrollY > 10);
  }, []);

  const handleResize = useCallback(() => {
    if (window.innerWidth >= 768 && isMenuOpen) {
      setIsMenuOpen(false);
    }
  }, [isMenuOpen]);

  useEffect(() => {
    let ticking = false;
    
    const optimizedScrollHandler = () => {
      if (!ticking) {
        requestAnimationFrame(() => {
          handleScroll();
          ticking = false;
        });
        ticking = true;
      }
    };

    window.addEventListener('scroll', optimizedScrollHandler, { passive: true });
    window.addEventListener('resize', handleResize, { passive: true });
    
    return () => {
      window.removeEventListener('scroll', optimizedScrollHandler);
      window.removeEventListener('resize', handleResize);
    };
  }, [handleScroll, handleResize]);

  const toggleMenu = useCallback(() => setIsMenuOpen(!isMenuOpen), [isMenuOpen]);

  return (
    <header 
      className={`fixed top-0 w-full z-50 transition-all duration-300 bg-white/95 backdrop-blur-sm will-change-transform ${
        isScrolled ? 'py-0 shadow-md' : 'py-0'
      }`}
    >
      <div className="container mx-auto px-4 w-full">
        <div className="max-w-7xl mx-auto flex items-center justify-between h-16 sm:h-20">
          {/* Optimized Logo */}
          <Link to="/" className="flex items-center flex-shrink-0">
            <img
              src="https://iili.io/FdNUvIV.png"
              alt="Jawbone Logo"
              className="h-12 sm:h-16 md:h-20 lg:h-24 w-auto logo-image"
              loading="eager"
              decoding="async"
              width="200"
              height="80"
            />
          </Link>

          {/* Desktop Navigation */}
          <nav className="hidden md:flex items-center space-x-4 lg:space-x-6 xl:space-x-8">
            <Link 
              to="/about"
              className="text-sm lg:text-base font-medium text-slate-700 transition-colors hover:text-secondary whitespace-nowrap"
            >
              About
            </Link>
            <Link 
              to="/services"
              className="text-sm lg:text-base font-medium text-slate-700 transition-colors hover:text-secondary whitespace-nowrap"
            >
              Services
            </Link>
            <Link 
              to="/support"
              className="text-sm lg:text-base font-medium text-slate-700 transition-colors hover:text-secondary whitespace-nowrap"
            >
              Support
            </Link>
            <Link 
              to="/contact"
              className="text-sm lg:text-base font-medium text-slate-700 transition-colors hover:text-secondary whitespace-nowrap"
            >
              Contact
            </Link>
            <Link to="/contact">
              <Button variant="primary" size="sm" className="whitespace-nowrap will-change-transform text-xs sm:text-sm">
                Get Your Free Assessment
              </Button>
            </Link>
          </nav>

          {/* Mobile Menu Button */}
          <button 
            className="md:hidden text-primary p-2 will-change-transform"
            onClick={toggleMenu}
            aria-label="Toggle menu"
          >
            {isMenuOpen ? <X className="h-6 w-6" /> : <Menu className="h-6 w-6" />}
          </button>
        </div>
      </div>

      {/* Mobile Menu */}
      {isMenuOpen && (
        <div className="md:hidden bg-white shadow-lg border-t border-slate-100 w-full">
          <div className="container mx-auto px-4 py-4 w-full">
            <div className="flex flex-col space-y-4">
              <Link 
                to="/about"
                className="text-slate-700 font-medium py-2 hover:text-secondary transition-colors"
                onClick={toggleMenu}
              >
                About
              </Link>
              <Link 
                to="/services"
                className="text-slate-700 font-medium py-2 hover:text-secondary transition-colors"
                onClick={toggleMenu}
              >
                Services
              </Link>
              <Link 
                to="/support"
                className="text-slate-700 font-medium py-2 hover:text-secondary transition-colors"
                onClick={toggleMenu}
              >
                Support
              </Link>
              <Link 
                to="/contact"
                className="text-slate-700 font-medium py-2 hover:text-secondary transition-colors"
                onClick={toggleMenu}
              >
                Contact
              </Link>
              <Link to="/contact" onClick={toggleMenu} className="w-full">
                <Button variant="primary" size="sm" className="mt-2 w-full">
                  Free Consultation
                </Button>
              </Link>
            </div>
          </div>
        </div>
      )}
    </header>
  );
});

Header.displayName = 'Header';

export default Header;